#ifndef CLOCK_PARTS_DRAW_H
#define CLOCK_PARTS_DRAW_H

/*!
  \file
  \brief テーマ時計の部品描画

  \author Satofumi KAMIMURA

  $Id$
*/

#include <QWidget>


class ClockPartsDraw : public QWidget {
  Q_OBJECT;

  ClockPartsDraw(const ClockPartsDraw& rhs);
  ClockPartsDraw& operator = (const ClockPartsDraw& rhs);

  struct pImpl;
  std::auto_ptr<pImpl> pimpl;

protected:
  void paintEvent(QPaintEvent* event);

public:
  explicit ClockPartsDraw(QWidget* parent = 0);
  ~ClockPartsDraw(void);

  /*!
    \brief テーマ時計の再描画を行う
  */
  void redraw(void);
};

#endif /* !CLOCK_PARTS_DRAW_H */
